#!/usr/bin/perl

use strict;
use warnings;
use Data::Dumper;
use Statistics::RankCorrelation;

# This script can be used to calculate Spearman's rho system-level 
# correlations between rankings calulated (using ./wmt10_sysRnk.pl) from the 
# WMT10 human segment-level rankings and automatic metric scores.
# Usage: 
# perl wmt10_rho.pl <automatic metric system-level score file excluding 
# reference> <human assessment system-level rank file excluding reference> 
# Input files should be in the format included in this distribution, both 
# files must contain scores for an identical set of systems, and the order 
# of systems must be identical in the two files.
# E.g.:
# perl wmt10_rho.pl Spanish-English-NIST-c-sys_noRef.scr
# data_RNK_Spanish-English.csv.sysRnk 

die "Expects two input files" unless scalar @ARGV == 2;

open FILE, '<', $ARGV[0] or die $ARGV[0];
my @linesA = <FILE>;
chomp( @linesA );
close FILE;

open FILE, '<', $ARGV[1] or die $ARGV[1];
my @linesB = <FILE>;
chomp( @linesB );
close FILE;

my @scoreA;
foreach my $lineA ( @linesA )
{
	die "malformed line A" unless $lineA =~ /^(.*)\t(.*)$/;
	push @scoreA, $2;
}

my @scoreB;
foreach my $lineB ( @linesB )
{
	die "malformed line B" unless $lineB =~ /^(.*)\t(.*)$/;
	push @scoreB, $2;
}


my %uniqueA;
my %uniqueB;
@uniqueA{ @scoreA } = @scoreA;
@uniqueB{ @scoreB } = @scoreB;

if ( ( values( %uniqueA ) == 1 ) or ( values( %uniqueB ) == 1 ) or scalar @scoreA < 2 )
{
	print STDOUT "N/A";
}
else
{
	my $corr = Statistics::RankCorrelation->new( [ @scoreA ], [ @scoreB ] );
	print STDOUT $corr->spearman;
	print "\n";
}
exit 0;
